Struct dlsite::DlsiteClient
source · pub struct DlsiteClient { /* private fields */ }Expand description
API client for DLsite.
Implementations
sourceimpl DlsiteClient
impl DlsiteClient
sourcepub async fn get_product_review(
&self,
product_id: &str,
limit: u32,
page: u32,
mix_pickup: bool,
order: ReviewSortOrder
) -> Result<ProductReview, DlsiteError>
pub async fn get_product_review( &self, product_id: &str, limit: u32, page: u32, mix_pickup: bool, order: ReviewSortOrder ) -> Result<ProductReview, DlsiteError>
Get product reviews and related informations.
Arguments
product_id- Product ID.mix_pickup- Mixes picked up review. To get user genre, this must be true.order- Sort order of reviews.limit- Number of reviews to get.page- Page number.
Returns
ProductReview- Product reviews and related informations.
sourceimpl DlsiteClient
impl DlsiteClient
sourcepub async fn get_product(
&self,
product_id: &str
) -> Result<Product, DlsiteError>
pub async fn get_product( &self, product_id: &str ) -> Result<Product, DlsiteError>
Get information about a product (also called “work”). This function will make 3 requests to DLsite: one to get the HTML page, one to get the AJAX data and one to get the review data. Especially, review data can be used as independent information.
Arguments
product_id- The product ID to get information about. Example:RJ123456. NOTE: This must be capitalized.
Example
use dlsite::{DlsiteClient, Product};
use tokio;
#[tokio::main]
async fn main() {
let client = DlsiteClient::new().unwrap();
let product = client.get_product("RJ123456").await.unwrap();
println!("{:#?}", product);
}sourceimpl DlsiteClient
impl DlsiteClient